summaryrefslogtreecommitdiff
path: root/compiler/GHC
diff options
context:
space:
mode:
authorTakenobu Tani <takenobu.hs@gmail.com>2020-05-27 22:43:46 +0900
committerMarge Bot <ben+marge-bot@smart-cactus.org>2020-06-01 06:39:05 -0400
commit11390e3ab038a18c2a7bf6b2423657614a439afb (patch)
treeeccde174cd2054fd87e89da0f6aa5eac2f1dd744 /compiler/GHC
parent7002d0cbbe1581dd157b530e95c62195f37cfe00 (diff)
downloadhaskell-11390e3ab038a18c2a7bf6b2423657614a439afb.tar.gz
Clean up file paths for new module hierarchy
This updates comments only. This patch replaces file references according to new module hierarchy. See also: * https://gitlab.haskell.org/ghc/ghc/-/wikis/Make-GHC-codebase-more-modular * https://gitlab.haskell.org/ghc/ghc/issues/13009
Diffstat (limited to 'compiler/GHC')
-rw-r--r--compiler/GHC/Cmm/Utils.hs2
-rw-r--r--compiler/GHC/CmmToAsm/SPARC/Base.hs2
-rw-r--r--compiler/GHC/Core/Coercion/Opt.hs2
-rw-r--r--compiler/GHC/Core/InstEnv.hs2
-rw-r--r--compiler/GHC/Core/Opt/ConstantFold.hs2
-rw-r--r--compiler/GHC/Core/TyCo/Tidy.hs2
-rw-r--r--compiler/GHC/Core/TyCon.hs2
-rw-r--r--compiler/GHC/Core/Unfold.hs2
-rw-r--r--compiler/GHC/HsToCore/PmCheck/Oracle.hs4
-rw-r--r--compiler/GHC/HsToCore/PmCheck/Types.hs2
-rw-r--r--compiler/GHC/Iface/Ext/Ast.hs2
-rw-r--r--compiler/GHC/Iface/Type.hs2
-rw-r--r--compiler/GHC/Parser/Lexer.x4
-rw-r--r--compiler/GHC/Runtime/Interpreter.hs2
-rw-r--r--compiler/GHC/StgToCmm/Expr.hs2
-rw-r--r--compiler/GHC/StgToCmm/Utils.hs2
-rw-r--r--compiler/GHC/SysTools/ExtraObj.hs2
-rw-r--r--compiler/GHC/Tc/Deriv.hs2
-rw-r--r--compiler/GHC/ThToHs.hs2
-rw-r--r--compiler/GHC/Utils/Outputable.hs2
-rw-r--r--compiler/GHC/Utils/Ppr.hs6
21 files changed, 25 insertions, 25 deletions
diff --git a/compiler/GHC/Cmm/Utils.hs b/compiler/GHC/Cmm/Utils.hs
index e81ccafb71..9679f4f311 100644
--- a/compiler/GHC/Cmm/Utils.hs
+++ b/compiler/GHC/Cmm/Utils.hs
@@ -542,7 +542,7 @@ toBlockListEntryFirst g
-- have both true and false successors. Block ordering can make a big difference
-- in performance in the LLVM backend. Note that we rely crucially on the order
-- of successors returned for CmmCondBranch by the NonLocal instance for CmmNode
--- defined in cmm/CmmNode.hs. -GBM
+-- defined in GHC/Cmm/Node.hs. -GBM
toBlockListEntryFirstFalseFallthrough :: CmmGraph -> [CmmBlock]
toBlockListEntryFirstFalseFallthrough g
| mapNull m = []
diff --git a/compiler/GHC/CmmToAsm/SPARC/Base.hs b/compiler/GHC/CmmToAsm/SPARC/Base.hs
index a7929081b3..bf71c172df 100644
--- a/compiler/GHC/CmmToAsm/SPARC/Base.hs
+++ b/compiler/GHC/CmmToAsm/SPARC/Base.hs
@@ -3,7 +3,7 @@
-- Also import the required constants, so we know what we're using.
--
-- In the interests of cross-compilation, we want to free ourselves
--- from the autoconf generated modules like main/Constants
+-- from the autoconf generated modules like GHC/Settings/Constants
module GHC.CmmToAsm.SPARC.Base (
wordLength,
diff --git a/compiler/GHC/Core/Coercion/Opt.hs b/compiler/GHC/Core/Coercion/Opt.hs
index e8a276e9ed..5b53936354 100644
--- a/compiler/GHC/Core/Coercion/Opt.hs
+++ b/compiler/GHC/Core/Coercion/Opt.hs
@@ -866,7 +866,7 @@ False) and that all is OK. But, all is not OK: we want to use the first branch
of the axiom in this case, not the second. The problem is that the parameters
of the first branch can unify with the supplied coercions, thus meaning that
the first branch should be taken. See also Note [Apartness] in
-types/FamInstEnv.hs.
+GHC/Core/FamInstEnv.hs.
Note [Why call checkAxInstCo during optimisation]
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
diff --git a/compiler/GHC/Core/InstEnv.hs b/compiler/GHC/Core/InstEnv.hs
index ef05747920..424a94e965 100644
--- a/compiler/GHC/Core/InstEnv.hs
+++ b/compiler/GHC/Core/InstEnv.hs
@@ -674,7 +674,7 @@ in this case by a little known `optimization' that was disabled in
an instance declaration. In this case, it silently inserts the `C
[a]', and everything happens to work out.
-(See `basicTypes/MkId:mkDictFunId' for the code in question. Search for
+(See `GHC/Types/Id/Make:mkDictFunId' for the code in question. Search for
`Mark Jones', although Mark claims no credit for the `optimization' in
question, and would rather it stopped being called the `Mark Jones
optimization' ;-)
diff --git a/compiler/GHC/Core/Opt/ConstantFold.hs b/compiler/GHC/Core/Opt/ConstantFold.hs
index 470b920e94..cc4324c536 100644
--- a/compiler/GHC/Core/Opt/ConstantFold.hs
+++ b/compiler/GHC/Core/Opt/ConstantFold.hs
@@ -1552,7 +1552,7 @@ match_inline (Type _ : e : _)
match_inline _ = Nothing
--- See Note [magicDictId magic] in `basicTypes/MkId.hs`
+-- See Note [magicDictId magic] in `GHC/Types/Id/Make.hs`
-- for a description of what is going on here.
match_magicDict :: [Expr CoreBndr] -> Maybe (Expr CoreBndr)
match_magicDict [Type _, Var wrap `App` Type a `App` Type _ `App` f, x, y ]
diff --git a/compiler/GHC/Core/TyCo/Tidy.hs b/compiler/GHC/Core/TyCo/Tidy.hs
index 8ec4b5818b..4674a0a2fe 100644
--- a/compiler/GHC/Core/TyCo/Tidy.hs
+++ b/compiler/GHC/Core/TyCo/Tidy.hs
@@ -146,7 +146,7 @@ tidyType env (CoercionTy co) = CoercionTy $! (tidyCo env co)
-- The following two functions differ from mkForAllTys and splitForAllTys in that
--- they expect/preserve the ArgFlag argument. These belong to types/Type.hs, but
+-- they expect/preserve the ArgFlag argument. These belong to GHC/Core/Type.hs, but
-- how should they be named?
mkForAllTys' :: [(TyCoVar, ArgFlag)] -> Type -> Type
mkForAllTys' tvvs ty = foldr strictMkForAllTy ty tvvs
diff --git a/compiler/GHC/Core/TyCon.hs b/compiler/GHC/Core/TyCon.hs
index fdff076567..1dc54f47bc 100644
--- a/compiler/GHC/Core/TyCon.hs
+++ b/compiler/GHC/Core/TyCon.hs
@@ -1372,7 +1372,7 @@ although it's probably true that we could merge some of these.
Roughly in order of "includes more information":
- - A Width (cmm/CmmType) is simply a binary value with the specified
+ - A Width (GHC/Cmm/Type) is simply a binary value with the specified
number of bits. It may represent a signed or unsigned integer, a
floating-point value, or an address.
diff --git a/compiler/GHC/Core/Unfold.hs b/compiler/GHC/Core/Unfold.hs
index f19d89ed59..ebfdaabea1 100644
--- a/compiler/GHC/Core/Unfold.hs
+++ b/compiler/GHC/Core/Unfold.hs
@@ -991,7 +991,7 @@ binary sizes shrink significantly either.
Note [Discounts and thresholds]
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-Constants for discounts and thesholds are defined in main/DynFlags,
+Constants for discounts and thesholds are defined in GHC/Driver/Session,
all of form ufXxxx. They are:
ufCreationThreshold
diff --git a/compiler/GHC/HsToCore/PmCheck/Oracle.hs b/compiler/GHC/HsToCore/PmCheck/Oracle.hs
index 633bfea12d..b2a4587b1b 100644
--- a/compiler/GHC/HsToCore/PmCheck/Oracle.hs
+++ b/compiler/GHC/HsToCore/PmCheck/Oracle.hs
@@ -1276,7 +1276,7 @@ for all other cases, apart from EmptyCase). This gave rise to #10746. Instead,
we do the following:
1. We normalise the outermost type family redex, data family redex or newtype,
- using pmTopNormaliseType (in types/FamInstEnv.hs). This computes 3
+ using pmTopNormaliseType (in GHC/Core/FamInstEnv.hs). This computes 3
things:
(a) A normalised type src_ty, which is equal to the type of the scrutinee in
source Haskell (does not normalise newtypes or data families)
@@ -1291,7 +1291,7 @@ we do the following:
newtype rewrite performed in (b).
For an example see also Note [Type normalisation]
- in types/FamInstEnv.hs.
+ in GHC/Core/FamInstEnv.hs.
2. Function Check.checkEmptyCase' performs the check:
- If core_ty is not an algebraic type, then we cannot check for
diff --git a/compiler/GHC/HsToCore/PmCheck/Types.hs b/compiler/GHC/HsToCore/PmCheck/Types.hs
index 310786b01c..8740c9acdb 100644
--- a/compiler/GHC/HsToCore/PmCheck/Types.hs
+++ b/compiler/GHC/HsToCore/PmCheck/Types.hs
@@ -271,7 +271,7 @@ The impact of this treatment of overloaded literals is the following:
* We have instant equality check for overloaded literals (we do not rely on
the term oracle which is rather expensive, both in terms of performance and
memory). This significantly improves the performance of functions `covered`
- `uncovered` and `divergent` in deSugar/Check.hs and effectively addresses
+ `uncovered` and `divergent` in GHC/HsToCore/PmCheck.hs and effectively addresses
#11161.
* The warnings issued are simpler.
diff --git a/compiler/GHC/Iface/Ext/Ast.hs b/compiler/GHC/Iface/Ext/Ast.hs
index ea0643351c..c50514ffe1 100644
--- a/compiler/GHC/Iface/Ext/Ast.hs
+++ b/compiler/GHC/Iface/Ext/Ast.hs
@@ -200,7 +200,7 @@ call and just recurse directly in to the subexpressions.
-}
--- These synonyms match those defined in main/GHC.hs
+-- These synonyms match those defined in compiler/GHC.hs
type RenamedSource = ( HsGroup GhcRn, [LImportDecl GhcRn]
, Maybe [(LIE GhcRn, Avails)]
, Maybe LHsDocString )
diff --git a/compiler/GHC/Iface/Type.hs b/compiler/GHC/Iface/Type.hs
index 63b6b33734..32df13d1ef 100644
--- a/compiler/GHC/Iface/Type.hs
+++ b/compiler/GHC/Iface/Type.hs
@@ -187,7 +187,7 @@ mkIfaceForAllTvBndr :: ArgFlag -> IfaceTvBndr -> IfaceForAllBndr
mkIfaceForAllTvBndr vis var = Bndr (IfaceTvBndr var) vis
-- | Build the 'tyConKind' from the binders and the result kind.
--- Keep in sync with 'mkTyConKind' in types/TyCon.
+-- Keep in sync with 'mkTyConKind' in GHC/Core/TyCon.
mkIfaceTyConKind :: [IfaceTyConBinder] -> IfaceKind -> IfaceKind
mkIfaceTyConKind bndrs res_kind = foldr mk res_kind bndrs
where
diff --git a/compiler/GHC/Parser/Lexer.x b/compiler/GHC/Parser/Lexer.x
index 7606dd3f9e..72f88e8018 100644
--- a/compiler/GHC/Parser/Lexer.x
+++ b/compiler/GHC/Parser/Lexer.x
@@ -119,7 +119,7 @@ import GHC.Parser.Annotation
-- -----------------------------------------------------------------------------
-- Alex "Character set macros"
--- NB: The logic behind these definitions is also reflected in basicTypes/Lexeme.hs
+-- NB: The logic behind these definitions is also reflected in GHC/Utils/Lexeme.hs
-- Any changes here should likely be reflected there.
$unispace = \x05 -- Trick Alex into handling Unicode. See [Unicode in Alex].
$nl = [\n\r\f]
@@ -2261,7 +2261,7 @@ adjustChar c = fromIntegral $ ord adj_c
-- with the actual character value hidden in the state.
| otherwise =
-- NB: The logic behind these definitions is also reflected
- -- in basicTypes/Lexeme.hs
+ -- in GHC/Utils/Lexeme.hs
-- Any changes here should likely be reflected there.
case generalCategory c of
diff --git a/compiler/GHC/Runtime/Interpreter.hs b/compiler/GHC/Runtime/Interpreter.hs
index b261a2b690..3229d003f6 100644
--- a/compiler/GHC/Runtime/Interpreter.hs
+++ b/compiler/GHC/Runtime/Interpreter.hs
@@ -166,7 +166,7 @@ Other Notes on Remote GHCi
~~~~~~~~~~~~~~~~~~~~~~~~~~
* This wiki page has an implementation overview:
https://gitlab.haskell.org/ghc/ghc/wikis/commentary/compiler/external-interpreter
- * Note [External GHCi pointers] in compiler/ghci/GHCi.hs
+ * Note [External GHCi pointers] in compiler/GHC/Runtime/Interpreter.hs
* Note [Remote Template Haskell] in libraries/ghci/GHCi/TH.hs
-}
diff --git a/compiler/GHC/StgToCmm/Expr.hs b/compiler/GHC/StgToCmm/Expr.hs
index b05da01d1b..3605b96149 100644
--- a/compiler/GHC/StgToCmm/Expr.hs
+++ b/compiler/GHC/StgToCmm/Expr.hs
@@ -902,7 +902,7 @@ cgIdApp fun_id args = do
--
-- Self-recursive tail calls can be optimized into a local jump in the same
-- way as let-no-escape bindings (see Note [What is a non-escaping let] in
--- stgSyn/CoreToStg.hs). Consider this:
+-- GHC/CoreToStg.hs). Consider this:
--
-- foo.info:
-- a = R1 // calling convention
diff --git a/compiler/GHC/StgToCmm/Utils.hs b/compiler/GHC/StgToCmm/Utils.hs
index 0660c6dd75..3fb18f0ea8 100644
--- a/compiler/GHC/StgToCmm/Utils.hs
+++ b/compiler/GHC/StgToCmm/Utils.hs
@@ -241,7 +241,7 @@ emitRtsCallGen res lbl args safe
-- here, as we don't have liveness information. And really, we
-- shouldn't be doing the workaround at this point in the pipeline, see
-- Note [Register parameter passing] and the ToDo on CmmCall in
--- cmm/CmmNode.hs. Right now the workaround is to avoid inlining across
+-- GHC/Cmm/Node.hs. Right now the workaround is to avoid inlining across
-- unsafe foreign calls in rewriteAssignments, but this is strictly
-- temporary.
callerSaveVolatileRegs :: DynFlags -> (CmmAGraph, CmmAGraph)
diff --git a/compiler/GHC/SysTools/ExtraObj.hs b/compiler/GHC/SysTools/ExtraObj.hs
index 46081df98c..1f1d8fd3d6 100644
--- a/compiler/GHC/SysTools/ExtraObj.hs
+++ b/compiler/GHC/SysTools/ExtraObj.hs
@@ -155,7 +155,7 @@ mkNoteObjsToLinkIntoBinary dflags dep_packages = do
-- ALL generated assembly must have this section to disable
-- executable stacks. See also
- -- compiler/nativeGen/AsmCodeGen.hs for another instance
+ -- compiler/GHC/CmmToAsm.hs for another instance
-- where we need to do this.
if platformHasGnuNonexecStack platform
then text ".section .note.GNU-stack,\"\","
diff --git a/compiler/GHC/Tc/Deriv.hs b/compiler/GHC/Tc/Deriv.hs
index eca079ed23..7819a8712e 100644
--- a/compiler/GHC/Tc/Deriv.hs
+++ b/compiler/GHC/Tc/Deriv.hs
@@ -452,7 +452,7 @@ makeDerivSpecs deriv_infos deriv_decls
-- | Process the derived classes in a single @deriving@ clause.
deriveClause :: TyCon
-> [(Name, TcTyVar)] -- Scoped type variables taken from tcTyConScopedTyVars
- -- See Note [Scoped tyvars in a TcTyCon] in types/TyCon
+ -- See Note [Scoped tyvars in a TcTyCon] in GHC/Core/TyCon
-> Maybe (LDerivStrategy GhcRn)
-> [LHsSigType GhcRn] -> SDoc
-> TcM [EarlyDerivSpec]
diff --git a/compiler/GHC/ThToHs.hs b/compiler/GHC/ThToHs.hs
index b6fb65df88..556b251f4c 100644
--- a/compiler/GHC/ThToHs.hs
+++ b/compiler/GHC/ThToHs.hs
@@ -2041,7 +2041,7 @@ specially in `GHC.HsToCore.Quote`, `GHC.ThToHs`, and
(where ty is the AST representation of t1 -> t2 -> ... -> tn -> t)
(b) When converting pattern synonyms from TH.Dec to HsSyn in
- `hsSyn/Convert.hs`, we convert their TH type signatures back to an
+ `GHC/ThToHs.hs`, we convert their TH type signatures back to an
appropriate Haskell pattern synonym type of the form
forall univs. reqs => forall exis. provs => t1 -> t2 -> ... -> tn -> t
diff --git a/compiler/GHC/Utils/Outputable.hs b/compiler/GHC/Utils/Outputable.hs
index 149713773d..9827e53f9e 100644
--- a/compiler/GHC/Utils/Outputable.hs
+++ b/compiler/GHC/Utils/Outputable.hs
@@ -1005,7 +1005,7 @@ pprHsBytes bs = let escaped = concatMap escape $ BS.unpack bs
else '\\' : show w
-- Postfix modifiers for unboxed literals.
--- See Note [Printing of literals in Core] in `basicTypes/Literal.hs`.
+-- See Note [Printing of literals in Core] in `GHC/Types/Literal.hs`.
primCharSuffix, primFloatSuffix, primIntSuffix :: SDoc
primDoubleSuffix, primWordSuffix, primInt64Suffix, primWord64Suffix :: SDoc
primCharSuffix = char '#'
diff --git a/compiler/GHC/Utils/Ppr.hs b/compiler/GHC/Utils/Ppr.hs
index 559088e415..96e1328ff7 100644
--- a/compiler/GHC/Utils/Ppr.hs
+++ b/compiler/GHC/Utils/Ppr.hs
@@ -21,7 +21,7 @@
-----------------------------------------------------------------------------
{-
-Note [Differences between libraries/pretty and compiler/utils/Pretty.hs]
+Note [Differences between libraries/pretty and compiler/GHC/Utils/Ppr.hs]
For historical reasons, there are two different copies of `Pretty` in the GHC
source tree:
@@ -29,7 +29,7 @@ source tree:
https://github.com/haskell/pretty. This is the `pretty` library as released
on hackage. It is used by several other libraries in the GHC source tree
(e.g. template-haskell and Cabal).
* `compiler/utils/Pretty.hs` (this module). It is used by GHC only.
There is an ongoing effort in https://github.com/haskell/pretty/issues/1 and
https://gitlab.haskell.org/ghc/ghc/issues/10735 to try to get rid of GHC's copy
@@ -49,7 +49,7 @@ ghc git tree:
$ cd libraries/pretty
$ git checkout v1.1.2.0
$ cd -
- $ vimdiff compiler/utils/Pretty.hs \
+ $ vimdiff compiler/GHC/Utils/Ppr.hs \
libraries/pretty/src/Text/PrettyPrint/HughesPJ.hs
For parity with `pretty-1.1.2.1`, the following two `pretty` commits would
@@ -29,7 +29,7 @@ source tree:
on hackage. It is used by several other libraries in the GHC source tree
(e.g. template-haskell and Cabal).
- * `compiler/utils/Pretty.hs` (this module). It is used by GHC only.
+ * `compiler/GHC/Utils/Ppr.hs` (this module). It is used by GHC only.
There is an ongoing effort in https://github.com/haskell/pretty/issues/1 and
https://gitlab.haskell.org/ghc/ghc/issues/10735 to try to get rid of GHC's copy